@@ -74,54 +74,61 @@ class SchemaValidator:
         else:
             self.validator_without_required_check.validate(data)
 
-    def get_sub_schema(self, path_to_sub_schema: list, current_sub_schema: dict = None):
+    def get_sub_schema(self, path_to_sub_schema: list, current_sub_schema: dict = None, depth: int = 0) -> (dict, int):
         if not current_sub_schema:
             current_sub_schema = self.schema
         next_element = path_to_sub_schema.__iter__()
         try:
             if "properties" in current_sub_schema:
                 n = next(next_element)
+                depth += 1
                 return self.get_sub_schema(
-                    path_to_sub_schema[1:], current_sub_schema["properties"][n],
+                    path_to_sub_schema[1:], current_sub_schema["properties"][n], depth
                 )
             elif "patternProperties" in current_sub_schema:
                 from re import compile
 
                 n = next(next_element)
+                depth += 1
                 for key in current_sub_schema["patternProperties"]:
                     if compile(key).match(n):
                         return self.get_sub_schema(
                             path_to_sub_schema[1:],
                             current_sub_schema["patternProperties"][key],
+                            depth
                         )
                 raise ValidationError(
                     f"none of the patternProperties matched: {list(current_sub_schema['patternProperties'].keys())}",
                 )
             elif "items" in current_sub_schema and next(next_element):
+                depth += 1
                 return self.get_sub_schema(
-                    path_to_sub_schema, current_sub_schema["items"],
+                    path_to_sub_schema, current_sub_schema["items"], depth
                 )
             elif "$ref" in current_sub_schema:
                 current_sub_schema = self.validator.resolver.resolve(
                     current_sub_schema["$ref"]
                 )
-                return self.get_sub_schema(path_to_sub_schema, current_sub_schema[1])
+                return self.get_sub_schema(path_to_sub_schema, current_sub_schema[1], depth)
 
             elif "oneOf" in current_sub_schema:
                 one_of_types = list()
+                depth += 1
                 for item in current_sub_schema["oneOf"]:
-                    one_of_types.append(self.get_sub_schema(path_to_sub_schema, item))
+                    depth -= 1
+                    schema_part, depth = self.get_sub_schema(path_to_sub_schema, item, depth)
+                    one_of_types.append(schema_part)
                 current_sub_schema = {"oneOf": one_of_types}
 
             elif next(next_element) in current_sub_schema:
                 n = path_to_sub_schema[0]
                 return self.get_sub_schema(
-                    path_to_sub_schema[1:], current_sub_schema[n]
+                    path_to_sub_schema[1:], current_sub_schema[n], depth
                 )
 
-            return current_sub_schema
+            return current_sub_schema, depth
         except StopIteration:
-            return current_sub_schema
+            return current_sub_schema, depth
 
     def validate_sub_part(self, new_data):
         paths_in_new_data, new_values = find_path_values_in_dict(new_data)
@@ -129,7 +136,13 @@ class SchemaValidator:
         for path_no in range(len(paths_in_new_data)):
             path_to_new_attribute = paths_in_new_data[path_no]
 
-            relevant_sub_schema = self.get_sub_schema(path_to_new_attribute)
+            relevant_sub_schema, depth = self.get_sub_schema(path_to_new_attribute)
+            if depth != len(paths_in_new_data[path_no]):
+                paths_in_new_data[path_no] = paths_in_new_data[path_no][:depth]
+                relevant_path = paths_in_new_data[path_no].copy()
+                new_values[path_no] = new_data.copy()
+                while relevant_path:
+                    new_values[path_no] = new_values[path_no][relevant_path.pop(0)]
             try:
                 self.__base_validator(
                     relevant_sub_schema, resolver=self.validator.resolver,
